from leinwand import Leinwand
class Stuhl:
    """
    Stellt einen Stuhl im Möbelplaner dar.
    """
    def __init__(self,xPosition=20,yPosition=20,breite=40,tiefe=45,farbe='rot'):
        """
        Erzeugt einen Stuhl an der gegebenen Position.
        xPosition: die x-Koordinate der oberen linken Ecke des Stuhls
        yPosition: die y-Koordinate der oberen linken Ecke des Stuhls
        breite: horizontale Ausdehnung bei winkel 0
        tiefe: vertikale Ausdehnung bei winkel 0
        farbe: die Farbe, in der der Stuhl angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.__xPosition = xPosition
        self.__yPosition = yPosition
        self.__breite = breite
        self.__tiefe = tiefe
        self.__winkel = 0
        self.__farbe = farbe
        self.__formen = []
        self.__leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Stuhl im Möbelplaner an.
        """
        if not self.__formen:
            sitzflaeche = self.__leinwand.polygon(self.__xPosition,self.__yPosition,\
                                                self.__xPosition+self.__breite,self.__yPosition,\
                                                self.__xPosition+self.__breite+5,self.__yPosition+self.__tiefe,\
                                                self.__xPosition-5,self.__yPosition+self.__tiefe)
            self.__leinwand.farbeAendern(sitzflaeche,"transparent")
            self.__leinwand.randfarbeAendern(sitzflaeche,self.__farbe)
            self.__formen.append(sitzflaeche)
            rueckenlehne = self.__leinwand.linie(self.__xPosition,self.__yPosition+5,\
                                                 self.__xPosition+self.__breite,self.__yPosition+5)
            self.__leinwand.farbeAendern(rueckenlehne,self.__farbe)
            self.__formen.append(rueckenlehne)
            xMitte,yMitte=self.__xPosition+self.__breite//2,self.__yPosition+self.__tiefe//2
            for form in self.__formen:
                self.__leinwand.drehe(form,xMitte,yMitte,self.__winkel)

    def verberge(self):
        """
        Entfernt diesen Stuhl aus der Ansicht im Möbelplaner.
        """
        for form in self.__formen:
            self.__leinwand.loesche(form)
        self.__formen = []

    def drehe(self,umWinkel):
        """
        Dreht den Stuhl.
        umWinkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        self.verberge()
        self.__winkel = (self.__winkel + umWinkel) % 360
        self.zeige()

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Stuhl in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Stuhl nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.__xPosition+=entfernung
        self.zeige()
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Stuhl in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Stuhl nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.__yPosition+=entfernung
        self.zeige()

    def breiteAendern(self,neueBreite):
        """
        Aendert die Breite des Stuhls
        neueBreite ersetzt den alten Wert
        """
        self.verberge()
        self.__breite = neueBreite
        self.zeige()
        
    def tiefeAendern(self,neueTiefe):
        """
        Aendert die Tiefe des Stuhls
        neueTiefe ersetzt den alten Wert
        """
        self.verberge()
        self.__tiefe = neueTiefe
        self.zeige()
        
