from leinwand import Leinwand
class Tisch:
    """
    Stellt einen Tisch im Möbelplaner dar.
    """
    def __init__(self,xPosition=50,yPosition=50,breite=120,tiefe=60,farbe='blau'):
        """
        Erzeugt einen Tisch an der gegebenen Position.
        xPosition: die x-Koordinate der Mitte des Tischs
        yPosition: die y-Koordinate der Mitte des Tischs
        breite: horizontale Ausdehnung bei winkel 0
        tiefe: vertikale Ausdehnung bei winkel 0
        farbe: die Farbe, in der der Tisch angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.__xPosition = xPosition
        self.__yPosition = yPosition
        self.__breite = breite
        self.__tiefe = tiefe
        self.__winkel = 0
        self.__farbe = farbe
        self.__formen = []
        self.__leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Tisch im Möbelplaner an.
        """
        if not self.__formen:
            tisch = self.__leinwand.polygon(self.__xPosition,self.__yPosition,\
                                          self.__xPosition+self.__breite,self.__yPosition,\
                                          self.__xPosition+self.__breite,self.__yPosition+self.__tiefe,\
                                          self.__xPosition,self.__yPosition+self.__tiefe)
            self.__leinwand.farbeAendern(tisch,"transparent")
            self.__leinwand.randfarbeAendern(tisch,self.__farbe)
            self.__formen.append(tisch)
            xMitte,yMitte=self.__xPosition+self.__breite//2,self.__yPosition+self.__tiefe//2
            for form in self.__formen:
                self.__leinwand.drehe(form,xMitte,yMitte,self.__winkel)

    def verberge(self):
        """
        Entfernt diesen Tisch aus der Ansicht im Möbelplaner.
        """
        for form in self.__formen:
            self.__leinwand.loesche(form)
        self.__formen = []

    def drehe(self,umWinkel):
        """
        Dreht den Tisch.
        umWinkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        self.verberge()
        self.__winkel = (self.__winkel + umWinkel) % 360
        self.zeige()

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Tisch in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.__xPosition+=entfernung
        self.zeige()
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Tisch in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.__yPosition+=entfernung
        self.zeige()

    def breiteAendern(self,neueBreite):
        """
        Aendert die Breite des Tischs
        neueBreite ersetzt den alten Wert
        """
        self.verberge()
        self.__breite = neueBreite
        self.zeige()
        
    def tiefeAendern(self,neueTiefe):
        """
        Aendert die Tiefe des Tischs
        neueTiefe ersetzt den alten Wert
        """
        self.verberge()
        self.__tiefe = neueTiefe
        self.zeige()
